# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/kscc/tender/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/kscc/tender/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Kscc\\Tender\\": "packages/kscc/tender/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Kscc\Tender\Providers\TenderServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Tender'  => Kscc\Tender\Facades\Tender::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Kscc\\TenderTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Kscc\Tender\Providers\TenderServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Kscc\Tender\Providers\TenderServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Kscc\Tender\Providers\TenderServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/tender/{modulename}

**User**

    http://path-to-route-folder/user/tender/{modulename}

**Public**

    http://path-to-route-folder/tenders


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/tender/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/tender/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/tender/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/tender/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/tender/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/tender/{modulename}/{slug}
    METHOD: GET