<?php

namespace Kscc\Tender\Policies;

use Litepie\User\Contracts\UserPolicy;
use Kscc\Tender\Models\Tender;

class TenderPolicy
{

    /**
     * Determine if the given user can view the tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tender $tender)
    {
        if ($user->canDo('tender.tender.view') && $user->isAdmin()) {
            return true;
        }

        return $tender->user_id == user_id() && $tender->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tender.tender.create');
    }

    /**
     * Determine if the given user can update the given tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tender $tender)
    {
        if ($user->canDo('tender.tender.edit') && $user->isAdmin()) {
            return true;
        }

        return $tender->user_id == user_id() && $tender->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tender $tender)
    {
        return $tender->user_id == user_id() && $tender->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tender $tender)
    {
        if ($user->canDo('tender.tender.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tender.
     *
     * @param UserPolicy $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tender $tender)
    {
        if ($user->canDo('tender.tender.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
